@@ -3,7 +3,7 @@ use std::path::PathBuf;
 
 use crate::{
     api::{ApiClient, BuildRecall},
-    global_config::read_global_config,
+    config_global::read_global_config,
 };
 
 pub async fn run_invite(global_config_dir: PathBuf) -> Result<()> {
@@ -16,7 +16,7 @@ pub async fn run_invite(global_config_dir: PathBuf) -> Result<()> {
         .context("Failed to create a new invite token")?;
 
     // Not a debug log, this is the output of this command
-    println!("{}", result.token);
+    println!("https://buildrecall.com/invite?token={}", result.token);
 
     Ok(())
 }
